@@ -5,7 +5,12 @@ from .color import color_to_color, gray
 try:
     import Rhino.Geometry as rg
 except ImportError as e:
-    raise ImportError("Failed to import Rhino Geometry.\n{}".format(e))
+    raise ImportError('Failed to import Rhino Geometry.\n{}'.format(e))
+
+try:
+    from ladybug_geometry.geometry2d.line import LineSegment2D
+except ImportError as e:
+    raise ImportError('Failed to import ladybug_geometry.\n{}'.format(e))
 
 
 """____________2D GEOMETRY TRANSLATORS____________"""
@@ -78,7 +83,7 @@ def from_point3d(point):
     return rg.Point3d(point.x, point.y, point.z)
 
 
-def from_ray3d(ray, z=0):
+def from_ray3d(ray):
     """Rhino Ray3d from ladybug Ray3D."""
     return rg.Ray3d(from_point3d(ray.p), from_vector3d(ray.v))
 
@@ -120,7 +125,7 @@ def from_mesh3d(mesh):
 def from_face3d(face):
     """Rhino Brep from ladybug Face3D."""
     segs = [from_linesegment3d(seg) for seg in face.boundary_segments]
-    brep = rg.Brep.	CreatePlanarBreps(segs, tolerance)[0]
+    brep = rg.Brep.CreatePlanarBreps(segs, tolerance)[0]
     if face.has_holes:
         for hole in face.hole_segments:
             trim_crvs = [from_linesegment3d(seg) for seg in hole]
@@ -139,28 +144,94 @@ def from_polyface3d(polyface):
 """________ADDITIONAL 3D GEOMETRY TRANSLATORS________"""
 
 
+def from_polyline2d_to_joined_polyline(polylines, z=0):
+    """Rhino PolylineCurve made by joining list of Polyline2D.
+
+    Args:
+        polylines: An array of Ladybug Polyline2D or LineSegment2D to be joined
+            into a polyline.
+        z: A number for the Z-coordinate. (Default: 0).
+
+    Returns:
+        A Rhino brep constructed from the polygon and the offset distance. If offset
+        is unsuccessful, just the polyline will be returned.
+    """
+    line_crv = []
+    for pl in polylines:
+        if isinstance(pl, LineSegment2D):
+            line_crv.append(from_linesegment2d(pl))
+        else:
+            line_crv.append(from_polyline2d(pl))
+    return rg.Curve.JoinCurves(line_crv)[0]
+
+
+def from_polyline2d_to_offset_brep(polylines, offset, z=0):
+    """Rhino Brep made by offsetting a joined list of Polyline2D inward.
+
+    Args:
+        polylines: An array of Ladybug Polyline2D or LineSegment2D to be joined
+            and translated to an offset Brep.
+        offset: A number for the distance to offset the Polygon inward.
+        z: A number for the Z-coordinate. (Default: 0).
+
+    Returns:
+        A Rhino brep constructed from the polygon and the offset distance. If offset
+        is unsuccessful, just the polyline will be returned.
+    """
+    curve = from_polyline2d_to_joined_polyline(polylines, z)
+    crv_style = rg.CurveOffsetCornerStyle.Sharp
+    all_curves = [curve]
+    off_curves = curve.Offset(rg.Plane.WorldXY, -offset, tolerance, crv_style)
+    if off_curves is not None:
+        all_curves.extend(off_curves)
+        offset_brep = rg.Brep.CreatePlanarBreps(all_curves)
+        if len(offset_brep) == 1:
+            if offset_brep[0].Loops.Count == 2:
+                return offset_brep[0]
+    return curve
+
+
 def from_face3d_to_wireframe(face):
-    """Rhino PolyLineCurve from ladybug Face3D."""
-    return rg.PolylineCurve(
-        [from_point3d(pt) for pt in face.boundary] + [from_point3d(face.boundary[0])])
+    """Rhino PolyLineCurves from ladybug Face3D.
+
+    Args:
+        face: A Ladybug Face3D object to be translated to a wireframe.
+
+    Returns:
+        A list of Rhino polyline curves for the boundary and holes in the face.
+    """
+    boundary = [_polyline_points(face.boundary)]
+    if face.has_holes:
+        return boundary + [_polyline_points(tup) for tup in face.holes]
+    return boundary
 
 
 def from_polyface3d_to_wireframe(polyface):
     """Rhino PolyLineCurve from ladybug Polyface3D."""
-    return [from_face3d_to_wireframe(face) for face in polyface.faces]
+    return [f for face in polyface.faces for f in from_face3d_to_wireframe(face)]
 
 
 def from_face3d_to_solid(face, offset):
-    """Rhino Solid Brep from a ladybug Face3D and an offset."""
+    """Rhino Solid Brep from a ladybug Face3D and an offset from the base face.
+
+    Args:
+        face: Ladybug geometry Face3D object.
+        offset: Number for the offset distance from the base face.
+    """
     srf_brep = from_face3d(face)
     return rg.Brep.CreateFromOffsetFace(
         srf_brep.Faces[0], offset, tolerance, False, True)
 
 
+def from_face3ds_to_joined_brep(faces):
+    """A list of joined Breps from an array of ladybug Face3D."""
+    return rg.Brep.JoinBreps([from_face3d(face) for face in faces], tolerance)
+
+
 def from_face3ds_to_colored_mesh(faces, color):
     """Colored Rhino mesh from an array of ladybug Face3D and ladybug Color.
 
-    This is used in workflows such as coloring Model geomtry with results.
+    This is used in workflows such as coloring Model geometry with results.
     """
     joined_mesh = rg.Mesh()
     for face in faces:
@@ -185,7 +256,8 @@ def _translate_mesh(mesh, pt_function):
             for pt in tuple(mesh[i] for i in face):
                 rhino_mesh.Vertices.Add(pt_function(pt))
             if len(face) == 4:
-                rhino_mesh.Faces.AddFace(_f_num, _f_num + 1, _f_num + 2, _f_num + 3)
+                rhino_mesh.Faces.AddFace(
+                    _f_num, _f_num + 1, _f_num + 2, _f_num + 3)
                 _f_num += 4
             else:
                 rhino_mesh.Faces.AddFace(_f_num, _f_num + 1, _f_num + 2)
@@ -213,3 +285,8 @@ def _translate_mesh(mesh, pt_function):
             for i, col in enumerate(mesh.colors):
                 rhino_mesh.VertexColors[i] = color_to_color(col)
     return rhino_mesh
+
+
+def _polyline_points(tup):
+    """Convert a tuple of Ladybug Geometry points to a Rhino Polyline."""
+    return rg.PolylineCurve([from_point3d(pt) for pt in tup] + [from_point3d(tup[0])])
